@@ -48,7 +48,7 @@ except ImportError:
 
 if yaml:
     def ordered_yaml_load(stream, Loader=yaml.Loader,
-                          object_pairs_hook=OrderedDict, **kwargs):
+                          object_pairs_hook=OrderedDict, *args, **kwargs):
         """
         Preserves order with OrderedDict as yaml is loaded
         Thanks to coldfix
@@ -137,25 +137,25 @@ class ParseException(Exception):
 
 # begin deserializers
 
-def _eval_xml(target, **kwargs):
+def _eval_xml(target, *args, **kwargs):
     root = et.parse(target).getroot()
     data = _element_to_odict(root)
     data = _first_list_in(data)
     return iter(data)
 
-def json_loader(target, **kwargs):
+def json_loader(target, *args, **kwargs):
     result = json.load(target, object_pairs_hook=OrderedDict)
     result = _ensure_rows(result)
     return iter(result)
 json_loader.__name__ = 'json_loader'
 
-def pickle_loader(target, **kwargs):
+def pickle_loader(target, *args, **kwargs):
     result = pickle.load(target)
     result = _ensure_rows(result)
     return iter(result)
 pickle_loader.__name__ = 'pickle_loader'
 
-def _eval_file_obj(target, **kwargs):
+def _eval_file_obj(target, *args, **kwargs):
     result = eval(target.read())
     if isinstance(result, list):
         for itm in result:
@@ -177,7 +177,7 @@ def _interpret_fieldnames(target, fieldnames):
             fieldnames = reader.__next__()
     return fieldnames
  
-def _eval_csv(target, fieldnames=None, **kwargs):
+def _eval_csv(target, fieldnames=None, *args, **kwargs):
     """
     Yields OrderedDicts from a CSV string
     """
@@ -195,7 +195,9 @@ def _table_score(tbl):
         score += 3
     return score
     
-def _html_to_odicts(html, **kwargs):
+def _html_to_odicts(html, *args, **kwargs):
+    if not bs4:
+        raise ImportError("BeautifulSoup4 not installed")
     soup = bs4.BeautifulSoup(html)
     tables = sorted(soup.find_all('table'), key=_table_score, reverse=True)
     if not tables:
@@ -301,6 +303,7 @@ class Source(object):
 
     def _deserialize(self, open_file):
         self.file = open_file
+        errors = []
         for deserializer in self.deserializers:
             self.file.seek(0)
             try:
@@ -326,8 +329,9 @@ class Source(object):
             except Exception as e:
                 logging.info('%s failed to deserialize %s' % (deserializer, open_file))
                 logging.info(str(e))
-        raise SyntaxError("%s: Could not deserialize %s (tried %s)" % (
-            self.table_name, open_file, ", ".join(self.deserializers)))
+                errors.append(str(e))
+        raise SyntaxError("%s: Could not deserialize %s (tried %s)\nErrors:\n%s" % (
+            self.table_name, open_file, ", ".join(str(s) for s in self.deserializers), "\n".join(errors)))
 
     def _source_is_path(self, src):
         (file_path, file_extension) = os.path.splitext(src)
@@ -352,10 +356,10 @@ class Source(object):
         if not requests:
             raise ImportError('must ``pip install requests to read from web``')
         (core_url, ext) = os.path.splitext(src)
-        ext = self._actual_ext_finder.search(ext).group(1)
-        ext = ext.lower()
+        ext = self._actual_ext_finder.search(ext)
+        ext = (ext and ext.group(1).lower()) or '.html'
         response = requests.get(src)
-        if ext.endswith('.xls'):
+        if ext and ext.endswith('.xls'):
             return self._source_is_excel(response.content)
         self.deserializers = self.eval_funcs_by_ext.get(ext or '*')
         if ext == '.pickle':
@@ -399,13 +403,13 @@ class Source(object):
         self._multiple_sources(generators)
 
     def __init__(self, src, limit=None, fieldnames=None):
-        """
+        '''
         For ``.csv`` and ``.xls``, field names will be taken from 
         the first line of data found - unless ``fieldnames`` is given,
         in which case, it will override.  For ``.xls``, ``fieldnames``
         may be an integer, in which case it will be the (1-based) row number
         field names will be taken from (rows before that will be discarded).
-        """
+        '''
         self.counter = 0
         self.limit = limit
         self.deserializers = []
